@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
 # Copyright 2006 Joe Wreschnig
-#           2016 Nick Boultbee
+#        2016,18 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -45,6 +44,7 @@ class Alarm(EventPlugin):
     def disabled(self):
         self._enabled = False
 
+    @staticmethod
     def is_valid_time(time):
         try:
             hour, minute = map(int, time.split(":"))
@@ -52,13 +52,12 @@ class Alarm(EventPlugin):
             return False
         else:
             return (hour < 24 and minute < 60)
-    is_valid_time = staticmethod(is_valid_time)
 
     def plugin_on_song_started(self, song):
         pass
 
     def _entry_changed(self, entries):
-        self._times = map(ValidatingEntry.get_text, entries)
+        self._times = [ValidatingEntry.get_text(e) for e in entries]
         config.set("plugins", self._pref_name, " ".join(self._times))
 
     def _ready(self):
