@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2005-2010   Joshua Kwan <joshk@triplehelix.org>,
 #                       Michael Ball <michael.ball@gmail.com>,
 #                       Steven Robertson <steven@strobe.cc>
@@ -78,7 +77,7 @@ class ResultComboBox(Gtk.ComboBox):
     """Formatted picker for different Result entries."""
 
     def __init__(self, model):
-        super(ResultComboBox, self).__init__(model=model)
+        super().__init__(model=model)
         render = Gtk.CellRendererText()
         render.set_fixed_height_from_font(2)
 
@@ -98,8 +97,8 @@ class ResultComboBox(Gtk.ComboBox):
             discs_text = numeric_phrase("%d disc", "%d discs", disc_count)
             tracks_text = numeric_phrase("%d track", "%d tracks", track_count)
 
-            markup = "<b>%s</b>\n%s - %s, %s (%s)" % (
-                    util.escape(release.title),
+            markup = "%s\n%s - %s, %s (%s)" % (
+                    util.bold(release.title),
                     util.escape(", ".join(artist_names)),
                     util.escape(discs_text),
                     util.escape(tracks_text),
@@ -119,7 +118,7 @@ class ResultTreeView(HintedTreeView, MultiDragTreeView):
         self.model = ObjectStore()
         self.model.append_many(album)
 
-        super(ResultTreeView, self).__init__(self.model)
+        super().__init__(self.model)
         self.set_headers_clickable(True)
         self.set_rules_hint(True)
         self.set_reorderable(True)
@@ -350,7 +349,7 @@ class SearchWindow(Dialog):
         self._qthread = QueryThread()
         self.current_release = None
 
-        super(SearchWindow, self).__init__(_("MusicBrainz lookup"))
+        super().__init__(_("MusicBrainz lookup"))
 
         self.add_button(_("_Cancel"), Gtk.ResponseType.REJECT)
         self.add_icon_button(_("_Save"), Icons.DOCUMENT_SAVE,
@@ -403,6 +402,8 @@ class SearchWindow(Dialog):
         sw.add(rtv)
         vb.pack_start(sw, True, True, 0)
 
+        # TODO: remove deprecated get_action_area
+        # https://developer.gnome.org/gtk3/stable/GtkDialog.html#gtk-dialog-get-action-area
         self.get_action_area().set_border_width(4)
         self.get_content_area().pack_start(vb, True, True, 0)
         self.connect('response', self._on_response)
@@ -444,12 +445,11 @@ class SearchWindow(Dialog):
         query = self.search_query.get_text()
 
         if not query:
-            self.result_label.set_markup(
-                "<b>%s</b>" % _("Please enter a query."))
+            self.result_label.set_markup(util.bold(_("Please enter a query.")))
             self.search_button.set_sensitive(True)
             return
 
-        self.result_label.set_markup("<i>%s</i>" % _(u"Searching…"))
+        self.result_label.set_markup(util.italic(_("Searching…")))
 
         self._qthread.add(self._process_results, search_releases, query)
 
@@ -470,7 +470,7 @@ class SearchWindow(Dialog):
         self._resultlist.append_many(results)
 
         if len(results) > 0:
-            self.result_label.set_markup("<i>%s</i>" % _(u"Loading result…"))
+            self.result_label.set_markup(util.italic(_("Loading result…")))
             self.result_combo.set_active(0)
         else:
             self.result_label.set_markup(_("No results found."))
@@ -486,7 +486,7 @@ class SearchWindow(Dialog):
         if release.id in self._releasecache:
             self._update_result(self._releasecache[release.id])
         else:
-            self.result_label.set_markup("<i>%s</i>" % _(u"Loading result…"))
+            self.result_label.set_markup(util.italic(_("Loading result…")))
             self.result_treeview.update_release(None)
             self._qthread.add(self._update_result, release.fetch_full)
 
